*** ./src/bin/psql/common.c.orig	Thu Mar 11 15:42:17 2004
--- ./src/bin/psql/common.c	Fri Mar 12 09:24:13 2004
***************
*** 345,350 ****
--- 345,537 ----
  }
  
  
+ #define DISPLAY_SIZE (60)
+ #define MIN_RIGHT_CUT (10)
+ #define EXTRACT_FORMAT "LINE %d: "
+ 
+ /* on errors, print syntax error position if available.
+  * the query is expected to be in the client encoding.
+  */
+ static void
+ ReportSyntaxErrorPosition(const PGresult *result, const char *query)
+ {
+ 	int loc = 0;
+ 	char * sp = PQresultErrorField(result, PG_DIAG_STATEMENT_POSITION);
+ 
+ 	if (sp && sscanf(sp, "%d", &loc)!=1)
+ 	{
+ 		psql_error("INTERNAL ERROR: unexpected statement position '%s'\n", sp);
+ 		return;
+ 	}
+ 	
+ 	/* do we have something to show? */
+ 	if (query!=NULL && loc>0)
+ 	{
+ 		int clen, slen, i, *qidx, ibeg, iend, last_nl, 
+ 			loc_line, nb_lines, prefix_len, figure_len;
+ 		char *wquery, *cursor, *ex_prefix, *sp_prefix;
+ 		bool beg_trunc, end_trunc;
+ 
+ 		/* (1) let us first compute a character index for the query. */
+ 
+ 		/* we need a safe allocation size... */
+ 		slen = strlen(query); 
+ 
+ 		/* the last one is needed to store last char mb length */
+ 		qidx = (int*) palloc(sizeof(int)*(slen+1));
+ 
+ 		qidx[0] = 0;
+ 		for (i=1; query[qidx[i-1]]!='\0' && i<slen+1; i++)
+ 			qidx[i] = qidx[i-1] + PQmblen(&query[qidx[i-1]], pset.encoding);
+ 		
+ 		clen = i-1;
+ 
+ 		/* we must be at the end! */
+ 		psql_assert(query[qidx[clen]] == '\0');
+ 
+ 		/* our localisation index start at 0! it must be in the query! */
+ 		loc--; 
+ 		psql_assert(loc>=0 && loc<clen);
+ 
+ 		/* (2) now we build a working copy of the query. */
+ 		wquery = (char*) palloc(sizeof(char)*(strlen(query)+1));
+ 		strcpy(wquery, query);
+ 
+ 		/* the character number of the last newline. */
+ 		last_nl = -1;
+ 		 /* input line number of our syntax error. */
+ 		loc_line = nb_lines = 1;
+ 		/* first included char of extract. */
+ 		ibeg = 0; 
+ 		/* last not-included char of extract. */
+ 		iend = clen; 
+ 
+ 		/* (3) we clean wquery string from tabs, carriage return and new lines.
+ 		 * extract error line number and begin and end indexes.
+ 		 */
+ 		for (i=0; i<clen; i++)
+ 		{
+ 			/* how to find a '\t', a '\r' or a '\n'? 
+ 			 * I assume here that all encodings must be ascii compatible...
+ 			 */
+ 			if ((qidx[i+1]-qidx[i]) == 1)
+ 			{
+ 				if (wquery[qidx[i]] == '\t') 
+ 					wquery[qidx[i]] = ' ';
+ 				if (wquery[qidx[i]] == '\r' || wquery[qidx[i]] == '\n')
+ 				{
+ 					/* count lines */
+ 					if (wquery[qidx[i]]=='\n')
+ 					{
+ 						nb_lines++;
+ 						if (i<loc) loc_line++;
+ 					}
+ 
+ 					/* set extract end. */
+ 					if (iend==clen && i>loc)
+ 						iend = i;
+ 
+ 					wquery[qidx[i]] = ' ';
+ 					last_nl = i;
+ 				}
+ 			}
+ 			/* set extract beginning. */
+ 			if (i==loc && last_nl!=-1)
+ 				ibeg = last_nl+1;
+ 		}
+ 
+ 		/* (4) if the line extracted is too long, we truncate it. */
+ 		beg_trunc = false;
+ 		end_trunc = false;
+ 		if (iend-ibeg > DISPLAY_SIZE)
+ 		{
+ 			/* we first truncate right if it is enough. */
+ 			if (ibeg+DISPLAY_SIZE > loc+MIN_RIGHT_CUT)
+ 			{
+ 				iend = ibeg+DISPLAY_SIZE;
+ 				end_trunc = true;
+ 			}
+ 			else
+ 			{
+ 				/* we truncate right. */
+ 				if (loc+MIN_RIGHT_CUT < iend)
+ 				{
+ 					iend = loc+MIN_RIGHT_CUT;
+ 					end_trunc = true;
+ 				}
+ 
+ 				/* still too long? 
+ 				 * we know that loc is at the end 
+ 				 * (loc+MIN_RIGHT_CUT>=iend from above)
+ 				 * now we truncate left.
+ 				 */
+ 				if (iend-ibeg > DISPLAY_SIZE)
+ 				{
+ 					ibeg = iend-DISPLAY_SIZE;
+ 					beg_trunc = true;
+ 				}
+ 			}
+ 		}
+ 		
+ 		/* (5) if the line is too short, we could fix it here. */
+ 
+ 		/* the extract MUST contain the localisation! */
+ 		psql_assert(ibeg<=loc && loc<iend);
+ 
+ 		/* (6) string to show cursor position under the extract. */
+ 		cursor = (char *) palloc(loc-ibeg+2);
+ 		for (i=0; i<loc-ibeg; i++)
+ 			cursor[i] = ' ';
+ 		cursor[i++] = '^';
+ 		cursor[i++] = '\0';
+ 
+ 		/* (7) now we show the resulting message. */
+ 
+ 		/* fix extract length for fprintf. */
+ 		wquery[qidx[iend]] = '\0';
+ 
+ 		prefix_len = strlen(EXTRACT_FORMAT) + 32;
+ 		ex_prefix = (char*) palloc(sizeof(char)*prefix_len);
+ 		sp_prefix = (char*) palloc(sizeof(char)*prefix_len);
+ 
+ 		if (snprintf(ex_prefix, prefix_len, EXTRACT_FORMAT, loc_line) >=
+ 			prefix_len)
+ 		{
+ 			/* very unlikely. */
+ 			psql_error("INTERNAL ERROR: bad alloc fmt=\"%s\" len=%d loc=%d\n",
+ 					   EXTRACT_FORMAT, prefix_len, loc_line);
+ 			pfree(ex_prefix);
+ 			pfree(sp_prefix);
+ 			pfree(wquery);
+ 			pfree(qidx);
+ 			pfree(cursor);
+ 			return;
+ 		}
+ 
+ 		/* actual len used? mbstrlen? how do we know that the locale 
+ 		 * translation is compatible with the client encoding?
+ 		 */
+ 		prefix_len = strlen(ex_prefix);
+ 		for (i=0; i<prefix_len; i++)
+ 			sp_prefix[i] = ' ';
+ 		sp_prefix[i] = '\0';
+ 
+ 		/* translator: this one is easy;-) */
+ 		psql_error("%s%s%s%s\n", ex_prefix,
+ 				   beg_trunc? "...": "", &wquery[qidx[ibeg]],
+ 				   end_trunc? "...": "");
+ 
+ 		psql_error("%s%s%s\n", sp_prefix, beg_trunc? "   ": "", cursor);
+ 		
+ 		/* clean */
+ 		pfree(ex_prefix);
+ 		pfree(sp_prefix);
+ 		pfree(wquery);
+ 		pfree(qidx);
+ 		pfree(cursor);
+ 	}
+ }
+ 
  /*
   * AcceptResult
   *
***************
*** 355,361 ****
   * Returns true for valid result, false for error state.
   */
  static bool
! AcceptResult(const PGresult *result)
  {
  	bool		OK = true;
  
--- 542,548 ----
   * Returns true for valid result, false for error state.
   */
  static bool
! AcceptResult(const PGresult *result, const char * query)
  {
  	bool		OK = true;
  
***************
*** 386,391 ****
--- 573,579 ----
  	if (!OK)
  	{
  		psql_error("%s", PQerrorMessage(pset.db));
+ 		ReportSyntaxErrorPosition(result, query);
  		CheckConnection();
  	}
  
***************
*** 449,455 ****
  
  	res = PQexec(pset.db, query);
  
! 	if (!AcceptResult(res) && res)
  	{
  		PQclear(res);
  		res = NULL;
--- 637,643 ----
  
  	res = PQexec(pset.db, query);
  
! 	if (!AcceptResult(res, query) && res)
  	{
  		PQclear(res);
  		res = NULL;
***************
*** 695,701 ****
  	results = PQexec(pset.db, query);
  
  	/* these operations are included in the timing result: */
! 	OK = (AcceptResult(results) && ProcessCopyResult(results));
  
  	if (pset.timing)
  		GETTIMEOFDAY(&after);
--- 883,889 ----
  	results = PQexec(pset.db, query);
  
  	/* these operations are included in the timing result: */
! 	OK = (AcceptResult(results, query) && ProcessCopyResult(results));
  
  	if (pset.timing)
  		GETTIMEOFDAY(&after);
*** ./src/test/regress/expected/errors.out.orig	Thu Mar 11 16:08:29 2004
--- ./src/test/regress/expected/errors.out	Fri Mar 12 09:30:54 2004
***************
*** 23,34 ****
--- 23,38 ----
  -- missing relation name 
  select;
  ERROR:  syntax error at or near ";" at character 7
+ LINE 1: select;
+               ^
  -- no such relation 
  select * from nonesuch;
  ERROR:  relation "nonesuch" does not exist
  -- missing target list
  select from pg_database;
  ERROR:  syntax error at or near "from" at character 8
+ LINE 1: select from pg_database;
+                ^
  -- bad name in target list
  select nonesuch from pg_database;
  ERROR:  column "nonesuch" does not exist
***************
*** 41,46 ****
--- 45,52 ----
  -- bad select distinct on syntax, distinct attribute missing
  select distinct on (foobar) from pg_database;
  ERROR:  syntax error at or near "from" at character 29
+ LINE 1: select distinct on (foobar) from pg_database;
+                                     ^
  -- bad select distinct on syntax, distinct attribute not in target list
  select distinct on (foobar) * from pg_database;
  ERROR:  column "foobar" does not exist
***************
*** 50,55 ****
--- 56,63 ----
  -- missing relation name (this had better not wildcard!) 
  delete from;
  ERROR:  syntax error at or near ";" at character 12
+ LINE 1: delete from;
+                    ^
  -- no such relation 
  delete from nonesuch;
  ERROR:  relation "nonesuch" does not exist
***************
*** 59,64 ****
--- 67,74 ----
  -- missing relation name (this had better not wildcard!) 
  drop table;
  ERROR:  syntax error at or near ";" at character 11
+ LINE 1: drop table;
+                   ^
  -- no such relation 
  drop table nonesuch;
  ERROR:  table "nonesuch" does not exist
***************
*** 69,74 ****
--- 79,86 ----
  -- missing relation name 
  alter table rename;
  ERROR:  syntax error at or near ";" at character 19
+ LINE 1: alter table rename;
+                           ^
  -- no such relation 
  alter table nonesuch rename to newnonesuch;
  ERROR:  relation "nonesuch" does not exist
***************
*** 123,131 ****
--- 135,147 ----
  -- missing index name 
  drop index;
  ERROR:  syntax error at or near ";" at character 11
+ LINE 1: drop index;
+                   ^
  -- bad index name 
  drop index 314159;
  ERROR:  syntax error at or near "314159" at character 12
+ LINE 1: drop index 314159;
+                    ^
  -- no such index 
  drop index nonesuch;
  ERROR:  index "nonesuch" does not exist
***************
*** 135,146 ****
--- 151,168 ----
  -- missing aggregate name 
  drop aggregate;
  ERROR:  syntax error at or near ";" at character 15
+ LINE 1: drop aggregate;
+                       ^
  -- missing aggregate type
  drop aggregate newcnt1;
  ERROR:  syntax error at or near ";" at character 23
+ LINE 1: drop aggregate newcnt1;
+                               ^
  -- bad aggregate name 
  drop aggregate 314159 (int);
  ERROR:  syntax error at or near "314159" at character 16
+ LINE 1: drop aggregate 314159 (int);
+                        ^
  -- bad aggregate type
  drop aggregate newcnt (nonesuch);
  ERROR:  type "nonesuch" does not exist
***************
*** 156,164 ****
--- 178,190 ----
  -- missing function name 
  drop function ();
  ERROR:  syntax error at or near "(" at character 15
+ LINE 1: drop function ();
+                       ^
  -- bad function name 
  drop function 314159();
  ERROR:  syntax error at or near "314159" at character 15
+ LINE 1: drop function 314159();
+                       ^
  -- no such function 
  drop function nonesuch();
  ERROR:  function nonesuch() does not exist
***************
*** 168,176 ****
--- 194,206 ----
  -- missing type name 
  drop type;
  ERROR:  syntax error at or near ";" at character 10
+ LINE 1: drop type;
+                  ^
  -- bad type name 
  drop type 314159;
  ERROR:  syntax error at or near "314159" at character 11
+ LINE 1: drop type 314159;
+                   ^
  -- no such type 
  drop type nonesuch;
  ERROR:  type "nonesuch" does not exist
***************
*** 180,200 ****
--- 210,242 ----
  -- missing everything 
  drop operator;
  ERROR:  syntax error at or near ";" at character 14
+ LINE 1: drop operator;
+                      ^
  -- bad operator name 
  drop operator equals;
  ERROR:  syntax error at or near ";" at character 21
+ LINE 1: drop operator equals;
+                             ^
  -- missing type list 
  drop operator ===;
  ERROR:  syntax error at or near ";" at character 18
+ LINE 1: drop operator ===;
+                          ^
  -- missing parentheses 
  drop operator int4, int4;
  ERROR:  syntax error at or near "," at character 19
+ LINE 1: drop operator int4, int4;
+                           ^
  -- missing operator name 
  drop operator (int4, int4);
  ERROR:  syntax error at or near "(" at character 15
+ LINE 1: drop operator (int4, int4);
+                       ^
  -- missing type list contents 
  drop operator === ();
  ERROR:  syntax error at or near ")" at character 20
+ LINE 1: drop operator === ();
+                            ^
  -- no such operator 
  drop operator === (int4);
  ERROR:  missing argument
***************
*** 209,214 ****
--- 251,258 ----
  -- no such type1 
  drop operator = ( , int4);
  ERROR:  syntax error at or near "," at character 19
+ LINE 1: drop operator = ( , int4);
+                           ^
  -- no such type1 
  drop operator = (nonesuch, int4);
  ERROR:  type nonesuch does not exist
***************
*** 218,244 ****
--- 262,300 ----
  -- no such type2 
  drop operator = (int4, );
  ERROR:  syntax error at or near ")" at character 24
+ LINE 1: drop operator = (int4, );
+                                ^
  --
  -- DROP RULE
   
  -- missing rule name 
  drop rule;
  ERROR:  syntax error at or near ";" at character 10
+ LINE 1: drop rule;
+                  ^
  -- bad rule name 
  drop rule 314159;
  ERROR:  syntax error at or near "314159" at character 11
+ LINE 1: drop rule 314159;
+                   ^
  -- no such rule 
  drop rule nonesuch on noplace;
  ERROR:  relation "noplace" does not exist
  -- bad keyword 
  drop tuple rule nonesuch;
  ERROR:  syntax error at or near "tuple" at character 6
+ LINE 1: drop tuple rule nonesuch;
+              ^
  -- no such rule 
  drop instance rule nonesuch on noplace;
  ERROR:  syntax error at or near "instance" at character 6
+ LINE 1: drop instance rule nonesuch on noplace;
+              ^
  -- no such rule 
  drop rewrite rule nonesuch;
  ERROR:  syntax error at or near "rewrite" at character 6
+ LINE 1: drop rewrite rule nonesuch;
+              ^
  --
  -- Check that division-by-zero is properly caught.
  --
***************
*** 264,266 ****
--- 320,443 ----
  ERROR:  division by zero
  select 1/0::float4;
  ERROR:  division by zero
+ --
+ -- Error Localisation
+ --
+ xxx;
+ ERROR:  syntax error at or near "xxx" at character 1
+ LINE 1: xxx;
+         ^
+ CREATE foo;
+ ERROR:  syntax error at or near "foo" at character 8
+ LINE 1: CREATE foo;
+                ^
+ CREATE TABLE ;
+ ERROR:  syntax error at or near ";" at character 14
+ LINE 1: CREATE TABLE ;
+                      ^
+ INSERT INTO foo VALUES(123) foo;
+ ERROR:  syntax error at or near "foo" at character 29
+ LINE 1: INSERT INTO foo VALUES(123) foo;
+                                     ^
+ INSERT INTO 123
+ VALUES(123);
+ ERROR:  syntax error at or near "123" at character 13
+ LINE 1: INSERT INTO 123
+                     ^
+ INSERT INTO foo 
+ VALUES(123) 123
+ ;
+ ERROR:  syntax error at or near "123" at character 30
+ LINE 2: VALUES(123) 123
+                     ^
+ -- with a tab
+ CREATE TABLE foo
+   (id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY,
+ 	id3 INTEGER NOT NUL,
+    id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL);
+ ERROR:  syntax error at or near "NUL" at character 94
+ LINE 3:  id3 INTEGER NOT NUL,
+                          ^
+ -- long line to be truncated on the left
+ CREATE TABLE foo(id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, 
+ id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL);
+ ERROR:  syntax error at or near "NUL" at character 90
+ LINE 1: ...T NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, 
+                                                                   ^
+ -- long line to be truncated on the right
+ CREATE TABLE foo(
+ id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL, id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY);
+ ERROR:  syntax error at or near "NUL" at character 35
+ LINE 2: id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQ...
+                         ^
+ -- long line to be truncated both ways
+ CREATE TABLE foo(id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL);
+ ERROR:  syntax error at or near "NUL" at character 90
+ LINE 1: ...L, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, id4 I...
+                                                              ^
+ -- long line to be truncated on the left, many lines
+ CREATE
+ TEMPORARY
+ TABLE 
+ foo(id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, 
+ id4 INT4 
+ UNIQUE 
+ NOT 
+ NULL, 
+ id5 TEXT 
+ UNIQUE 
+ NOT 
+ NULL)
+ ;
+ ERROR:  syntax error at or near "NUL" at character 101
+ LINE 4: ...T NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, 
+                                                                   ^
+ -- long line to be truncated on the right, many lines
+ CREATE 
+ TEMPORARY
+ TABLE 
+ foo(
+ id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL, id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY)
+ ;
+ ERROR:  syntax error at or near "NUL" at character 47
+ LINE 5: id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQ...
+                         ^
+ -- long line to be truncated both ways, many lines
+ CREATE 
+ TEMPORARY
+ TABLE 
+ foo
+ (id 
+ INT4 
+ UNIQUE NOT NULL, idx INT4 UNIQUE NOT NULL, idy INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL, 
+ idz INT4 UNIQUE NOT NULL, 
+ idv INT4 UNIQUE NOT NULL);
+ ERROR:  syntax error at or near "NUL" at character 157
+ LINE 7: ...L, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, id4 I...
+                                                              ^
+ -- more that 10 lines...
+ CREATE 
+ TEMPORARY
+ TABLE 
+ foo
+ (id 
+ INT4 
+ UNIQUE 
+ NOT 
+ NULL
+ , 
+ idm
+ INT4 
+ UNIQUE 
+ NOT 
+ NULL,
+ idx INT4 UNIQUE NOT NULL, idy INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL, 
+ idz INT4 UNIQUE NOT NULL, 
+ idv 
+ INT4 
+ UNIQUE 
+ NOT 
+ NULL);
+ ERROR:  syntax error at or near "NUL" at character 190
+ LINE 16: ...L, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, id4 I...
+                                                               ^
*** ./src/test/regress/expected/strings.out.orig	Thu Mar 11 16:01:29 2004
--- ./src/test/regress/expected/strings.out	Fri Mar 12 09:33:21 2004
***************
*** 19,24 ****
--- 19,26 ----
  ' - third line'
  	AS "Illegal comment within continuation";
  ERROR:  syntax error at or near "' - third line'" at character 75
+ LINE 3: ' - third line'
+         ^
  --
  -- test conversions between various string types
  -- E021-10 implicit casting among the character data types
*** ./src/test/regress/output/constraints.source.orig	Thu Mar 11 18:56:43 2004
--- ./src/test/regress/output/constraints.source	Fri Mar 12 09:32:09 2004
***************
*** 46,56 ****
--- 46,60 ----
  --  test for extraneous comma
  CREATE TABLE error_tbl (i int DEFAULT (100, ));
  ERROR:  syntax error at or near "," at character 43
+ LINE 1: CREATE TABLE error_tbl (i int DEFAULT (100, ));
+                                                   ^
  --  this will fail because gram.y uses b_expr not a_expr for defaults,
  --  to avoid a shift/reduce conflict that arises from NOT NULL being
  --  part of the column definition syntax:
  CREATE TABLE error_tbl (b1 bool DEFAULT 1 IN (1, 2));
  ERROR:  syntax error at or near "IN" at character 43
+ LINE 1: CREATE TABLE error_tbl (b1 bool DEFAULT 1 IN (1, 2));
+                                                   ^
  --  this should work, however:
  CREATE TABLE error_tbl (b1 bool DEFAULT (1 IN (1, 2)));
  DROP TABLE error_tbl;
*** ./src/test/regress/output/create_function_1.source.orig	Thu Mar 11 18:56:43 2004
--- ./src/test/regress/output/create_function_1.source	Fri Mar 12 09:32:34 2004
***************
*** 55,60 ****
--- 55,62 ----
  CREATE FUNCTION test1 (int) RETURNS int LANGUAGE sql
      AS 'not even SQL';
  ERROR:  syntax error at or near "not" at character 1
+ LINE 1: CREATE FUNCTION test1 (int) RETURNS int LANGUAGE sql
+         ^
  CREATE FUNCTION test1 (int) RETURNS int LANGUAGE sql
      AS 'SELECT 1, 2, 3;';
  ERROR:  return type mismatch in function declared to return integer
*** ./src/test/regress/sql/errors.sql.orig	Thu Mar 11 15:45:47 2004
--- ./src/test/regress/sql/errors.sql	Fri Mar 12 09:27:55 2004
***************
*** 276,278 ****
--- 276,373 ----
  select 1::float4/0;
  
  select 1/0::float4;
+ 
+ 
+ --
+ -- Error Localisation
+ --
+ 
+ xxx;
+ 
+ CREATE foo;
+ 
+ CREATE TABLE ;
+ 
+ INSERT INTO foo VALUES(123) foo;
+ 
+ INSERT INTO 123
+ VALUES(123);
+ 
+ INSERT INTO foo 
+ VALUES(123) 123
+ ;
+ 
+ -- with a tab
+ CREATE TABLE foo
+   (id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY,
+ 	id3 INTEGER NOT NUL,
+    id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL);
+ 
+ -- long line to be truncated on the left
+ CREATE TABLE foo(id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, 
+ id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL);
+ 
+ -- long line to be truncated on the right
+ CREATE TABLE foo(
+ id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL, id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY);
+ 
+ -- long line to be truncated both ways
+ CREATE TABLE foo(id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL);
+ 
+ -- long line to be truncated on the left, many lines
+ CREATE
+ TEMPORARY
+ TABLE 
+ foo(id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, 
+ id4 INT4 
+ UNIQUE 
+ NOT 
+ NULL, 
+ id5 TEXT 
+ UNIQUE 
+ NOT 
+ NULL)
+ ;
+ 
+ -- long line to be truncated on the right, many lines
+ CREATE 
+ TEMPORARY
+ TABLE 
+ foo(
+ id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL, id INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY)
+ ;
+ 
+ -- long line to be truncated both ways, many lines
+ CREATE 
+ TEMPORARY
+ TABLE 
+ foo
+ (id 
+ INT4 
+ UNIQUE NOT NULL, idx INT4 UNIQUE NOT NULL, idy INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL, 
+ idz INT4 UNIQUE NOT NULL, 
+ idv INT4 UNIQUE NOT NULL);
+ 
+ -- more that 10 lines...
+ CREATE 
+ TEMPORARY
+ TABLE 
+ foo
+ (id 
+ INT4 
+ UNIQUE 
+ NOT 
+ NULL
+ , 
+ idm
+ INT4 
+ UNIQUE 
+ NOT 
+ NULL,
+ idx INT4 UNIQUE NOT NULL, idy INT4 UNIQUE NOT NULL, id2 TEXT NOT NULL PRIMARY KEY, id3 INTEGER NOT NUL, id4 INT4 UNIQUE NOT NULL, id5 TEXT UNIQUE NOT NULL, 
+ idz INT4 UNIQUE NOT NULL, 
+ idv 
+ INT4 
+ UNIQUE 
+ NOT 
+ NULL);
